@@ -53,15 +53,10 @@ end
 if ischar(obj.transform)
   orientn = find(strcmpi(obj.transform, {'axial', ... 
             'coronal', ...
-            'sagittal', ...
             'sagittal'}));
   if isempty(orientn)
     error('Unexpected orientation %s', obj.transform);
   end
-  if orientn == 4
-    warning('fill_defaults:spelling', ...
-        'Goofy spelling of sagittal, but we''ll let you off');
-  end
   ts = [0 0 0 0 0 0 1 1 1;...
       0 0 0 pi/2 0 0 1 -1 1;...
       0 0 0 pi/2 0 -pi/2 -1 1 1];
