@@ -1,6 +1,7 @@
-function spm_check_registration(images)
+function spm_check_registration(images, captions, varargin)
 % A visual check of image registration quality.
 % FORMAT spm_check_registration
+% FORMAT spm_check_registration(images, captions)
 % Orthogonal views of one or more images are displayed. Clicking in
 % any image moves the centre of the orthogonal views. Images are
 % shown in orientations relative to that of the first selected image.
@@ -11,7 +12,7 @@ function spm_check_registration(images)
 % Copyright (C) 1997-2011 Wellcome Trust Centre for Neuroimaging
 
 % John Ashburner
-% $Id: spm_check_registration.m 4205 2011-02-21 15:39:08Z guillaume $
+% $Id: spm_check_registration.m 4330 2011-05-23 18:04:16Z ged $
 
 
 if ~nargin
@@ -38,4 +39,11 @@ for ij=1:mn
         [j+ds/2 i+ds/2 w-ds h-ds]);
     if ij==1, spm_orthviews('Space'); end
     spm_orthviews('AddContext',handle);
+    if nargin > 1 && ~isempty(captions)
+        captions = cellstr(captions);
+        mn = numel(captions);
+        if ij <= mn
+            spm_orthviews('Caption', ij, captions{ij}, varargin{:});
+        end
+    end
 end
