@@ -61,7 +61,7 @@ function bma = spm_dcm_bma(post,post_indx,subj,Nsamp,oddsr)
 % Copyright (C) 2009 Wellcome Trust Centre for Neuroimaging
 
 % Will Penny
-% $Id: spm_dcm_bma.m 4548 2011-11-04 16:50:58Z will $
+% $Id: spm_dcm_bma.m 4736 2012-05-11 11:26:56Z will $
 
 if nargin < 4 || isempty(Nsamp)
     Nsamp = 1e3;
@@ -84,6 +84,7 @@ else
     dcm_fmri = 0;
 end
 
+
 firstsub  = 1;
 firstmod  = 1;
 
@@ -305,15 +306,16 @@ Np = length(params(firstsub).model(firstmod).vEp);
 if dcm_fmri
 
     Nr      = nreg*nreg;
-
+    nmods   = size(DCM.Ep.B,3);
+    
     Etmp.A  = zeros(nreg,nreg,Nsamp);
-    Etmp.B  = zeros(nreg,nreg,min,Nsamp);
+    Etmp.B  = zeros(nreg,nreg,nmods,Nsamp);
     Etmp.C  = zeros(nreg,min,Nsamp);
     Etmp.D  = zeros(nreg,nreg,dimD,Nsamp);
 
     dima    = Nr;
-    dimb    = Nr+Nr*min;
-    dimc    = Nr+Nr*min+nreg*min;
+    dimb    = Nr+Nr*nmods;
+    dimc    = Nr+Nr*nmods+nreg*min;
 
 end
 
