@@ -7,7 +7,7 @@ function D = spm_eeg_inv_vbecd_gui(D,val)
 %__________________________________________________________________________
 % Copyright (C) 2008 Wellcome Trust Centre for Neuroimaging
 % 
-% $Id: spm_eeg_inv_vbecd_gui.m 4210 2011-02-23 11:02:32Z gareth $
+% $Id: spm_eeg_inv_vbecd_gui.m 4531 2011-10-21 11:49:08Z gareth $
 
 %%
 % Load data, if necessary
@@ -16,6 +16,8 @@ if nargin<1
     D = spm_eeg_load;
 end
 
+DISTTHRESH=120; %% mm distance from centre of brain classified as inside the head
+
 %%
 % Check if the forward model was prepared & handle the other info bits
 %========================================
@@ -98,7 +100,7 @@ if isfield(D.inv{val}, 'forward') && isfield(D.inv{val}, 'datareg')
          
             %disp('Fixing sphere centre !');
             %P.forward.vol.o=[0 0 28]; P.forward.vol.r=100;
-            mnivol = ft_transform_vol(M1, P.forward.vol); %% used for inside head calculation
+            %mnivol = ft_transform_vol(M1, P.forward.vol); %% used for inside head calculation
             
             
         end
@@ -256,7 +258,11 @@ while adding_dips
             while 1
                 s0mni = spm_input(str, 1+tr_q+dip_q+2,'e',[0 0 0])';
                 
-                outside = ~ft_inside_vol(s0mni',mnivol);
+                %outside = ~ft_inside_vol(s0mni',mnivol);
+                
+                distcentre=sqrt(dot(s0mni'-mean(D.inv{D.val}.mesh.tess_mni.vert),s0mni'-mean(D.inv{D.val}.mesh.tess_mni.vert))); %% 
+                outside=(distcentre>DISTTHRESH);
+                    
                 s0=D.inv{val}.datareg.fromMNI*[s0mni' 1]';
                 s0=s0(1:3);
                 
@@ -292,7 +298,7 @@ while adding_dips
             str2='Prior moment variance (nAm2)';
             diags_w0_mni = spm_input(str2, 1+tr_q+dip_q+2,'e',priormomvardefault)';
             dip_pr(dip_q).mu_w0 =orM1*w0_mni;
-            S_w0_ctf=orM1*w0_mni*orM1';
+            S_w0_ctf=orM1*diag(diags_w0_mni)*orM1';
             
              
         else
@@ -321,7 +327,11 @@ while adding_dips
                 s0mni = spm_input(str, 1+tr_q+dip_q+2,'e',[0 0 0])';
                 syms0mni=s0mni;
                 syms0mni(1)=-syms0mni(1);
-                outside = ~ft_inside_vol(s0mni',mnivol);
+                
+                
+                distcentre=sqrt(dot(s0mni'-mean(D.inv{D.val}.mesh.tess_mni.vert),s0mni'-mean(D.inv{D.val}.mesh.tess_mni.vert))); %% 
+                outside=(distcentre>DISTTHRESH);
+                
                 s0=D.inv{val}.datareg.fromMNI*[s0mni' 1]';
                 
                 s0sym=D.inv{val}.datareg.fromMNI*[syms0mni' 1]';
