@@ -6,24 +6,26 @@ function [xy,label] = spm_eeg_layout3D(sens, modality)
 % Copyright (C) 2008 Wellcome Trust Centre for Neuroimaging
 
 % Vladimir Litvak
-% $Id: spm_eeg_layout3D.m 2720 2009-02-09 19:50:46Z vladimir $
+% $Id: spm_eeg_layout3D.m 5141 2012-12-20 15:54:55Z vladimir $
 
 
 switch modality
     case 'EEG'
-        xy = sens.pnt;
+        xy = sens.chanpos;
         label = sens.label;
     case 'MEG'
         cfg = [];
         cfg.style = '3d';
         cfg.rotate = 0;
         cfg.grad = sens;
+        cfg.showcallinfo = 'no';
 
         lay = ft_prepare_layout(cfg);
 
         [sel1, sel2] = spm_match_str(sens.label, lay.label);
 
-        label = lay.label(sel2, 1);
+        label = lay.label(:);
+        label = label(sel2, 1);
         xy = lay.pos(sel2, :);
 end
 
