@@ -69,7 +69,7 @@ function varargout = spm_mip_ui(varargin)
 % Copyright (C) 2008 Wellcome Trust Centre for Neuroimaging
 
 % Andrew Holmes
-% $Id: spm_mip_ui.m 4404 2011-07-22 11:36:40Z volkmar $
+% $Id: spm_mip_ui.m 4860 2012-08-24 13:23:55Z volkmar $
 
 
 %==========================================================================
@@ -154,7 +154,7 @@ end
 %-MIP pane dimensions, origin offsets and #pixels per mm
 %-See spm_project.c for derivation
 mipmat = spm_get_defaults('stats.results.mipmat');
-load(mipmat, 'DXYZ', 'CXYZ', 'scale');
+load(char(mipmat), 'DXYZ', 'CXYZ', 'scale');
 % DMIP = [DXYZ(2)+DXYZ(1), DXYZ(1)+DXYZ(3)];
 %-Coordinates of Talairach origin in multipane MIP image (Axes are 'ij' + rot90)
 % Transverse: [Po(1), Po(2)]
