@@ -1,19 +1,19 @@
 function C = spm_orthpoly(N,K)
-% Creates orthogonal polynomial basis functions.
-% FORMAT C = spm_dctmtx(N,K)
+% Create orthonormal polynomial basis functions
+% FORMAT C = spm_orthpoly(N,[K])
 % N - dimension
 % K - order
 %__________________________________________________________________________
 % spm_orthpoly creates a matrix for the first few basis functions of an
 % orthogonal polynomial expansion
 %__________________________________________________________________________
-% Copyright (C) 2008 Wellcome Trust Centre for Neuroimaging
+% Copyright (C) 2007 Wellcome Trust Centre for Neuroimaging
 
 % Karl Friston
-% $Id: spm_orthpoly.m 1143 2008-02-07 19:33:33Z spm $
+% $Id: spm_orthpoly.m 4310 2011-04-18 16:07:35Z guillaume $
 
 %--------------------------------------------------------------------------
-if nargin == 1, K = N; end;
+if nargin == 1, K = N; end
 C     = zeros(N,K + 1);
 x     = [1:N]';
 for i = 0:K
