@@ -21,7 +21,7 @@ function [stats,talpositions,gridpositions,grid,fftnewdata,alllf,allepochdata]=s
 % Copyright (C) 2009 Institute of Neurology, UCL
 
 % Gareth Barnes
-% $Id: spm_eeg_ft_beamformer_cva.m 4377 2011-06-27 09:54:33Z gareth $
+% $Id: spm_eeg_ft_beamformer_cva.m 5178 2013-01-07 11:58:30Z ged $
 
 [Finter,Fgraph] = spm('FnUIsetup','Multivariate LCMV beamformer for power', 0);
 %%
@@ -432,6 +432,7 @@ end;
 
 cfg.feedback='off';
 cfg.inwardshift           = -S.gridstep; % mm
+cfg.sourceunits = 'mm';
 
 if ~isfield(S,'grid'),
     
@@ -514,7 +515,7 @@ disp('now running through freq bands and constructing t stat images');
 origfftnewdata=fftnewdata;
 for boot=1:Nboot,
     
-    bttrials=randi(Ntrials,Ntrials,1);
+    bttrials=floor(rand(1,Ntrials)*Ntrials)+1;
     if boot==1,
         bttrials=1:Ntrials;
     else
@@ -928,26 +929,26 @@ for boot=1:Nboot,
             cfg1.sourceunits   = 'mm';
             cfg1.parameter = 'pow_maxchi';
             cfg1.downsample = 1;
-            sourceint_pow_maxchi = ft_sourceinterpolate(cfg1, csource, sMRI);
+            sourceint_pow_maxchi = ft_sourceinterpolate(cfg1, csource, ft_read_mri(sMRI, 'format', 'nifti_spm'));
             
             cfg1 = [];
             cfg1.sourceunits   = 'mm';
             cfg1.parameter = 'evoked_maxchi';
             cfg1.downsample = 1;
-            sourceint_evoked_maxchi = ft_sourceinterpolate(cfg1, csource, sMRI);
+            sourceint_evoked_maxchi = ft_sourceinterpolate(cfg1, csource, ft_read_mri(sMRI, 'format', 'nifti_spm'));
             
             
             cfg1 = [];
             cfg1.sourceunits   = 'mm';
             cfg1.parameter = 'logp_power';
             cfg1.downsample = 1;
-            sourceint_logp_pow = ft_sourceinterpolate(cfg1, csource, sMRI);
+            sourceint_logp_pow = ft_sourceinterpolate(cfg1, csource, ft_read_mri(sMRI, 'format', 'nifti_spm'));
             
             cfg1 = [];
             cfg1.sourceunits   = 'mm';
             cfg1.parameter = 'logp_evoked';
             cfg1.downsample = 1;
-            sourceint_logp_evoked = ft_sourceinterpolate(cfg1, csource, sMRI);
+            sourceint_logp_evoked = ft_sourceinterpolate(cfg1, csource, ft_read_mri(sMRI, 'format', 'nifti_spm'));
             
             
             
@@ -1075,7 +1076,7 @@ cfg1 = [];
 cfg1.sourceunits   = 'mm';
 cfg1.parameter = 'pow_maxchi';
 cfg1.downsample = 1;
-sourceint_pow_maxchi = ft_sourceinterpolate(cfg1, csource, sMRI);
+sourceint_pow_maxchi = ft_sourceinterpolate(cfg1, csource, ft_read_mri(sMRI, 'format', 'nifti_spm'));
 
 
 cfg = [];
