@@ -18,17 +18,27 @@ function [u] = spm_erp_u(t,P,M)
 % Copyright (C) 2005 Wellcome Trust Centre for Neuroimaging
  
 % Karl Friston
-% $Id: spm_erp_u.m 3653 2009-12-23 20:06:48Z karl $
-
-
-% stimulus - subcortical impulse
+% $Id: spm_erp_u.m 4567 2011-11-23 12:13:01Z spm $
+ 
+ 
+% preliminaries - check durations (ms)
+%--------------------------------------------------------------------------
+try
+    if length(M.dur) ~= length(M.ons)
+        M.dur = M.dur(1) + M.ons - M.ons;
+    end
+catch
+    M.dur = 32 + M.ons - M.ons;
+end
+ 
+% stimulus  Gaussian (subcortical) impulse
 %--------------------------------------------------------------------------
 nu    = length(M.ons);
 u     = sparse(length(t),nu);
 t     = t*1000;
 for i = 1:nu
-   delay  = M.ons(i)  +  P.R(i,1)*128;
-   scale  = M.ons(i)*exp(P.R(i,2));
-   u(:,i) = exp(-(t - delay).^2/scale)*32;
+   delay  = M.ons(i) +   P.R(i,1)*128;
+   scale  = M.dur(i)*exp(P.R(i,2));
+   u(:,i) = exp(-(t - delay).^2/(2*scale^2))*32;
 end
 
